Learn R Programming

HTGM2D (version 1.1.1)

Jaccard: Jaccard

Description

create the heat map data that is needed as input to JaccardHeatMap()

Usage

Jaccard(dir, m1, m2, thresh1 = 2, thresh2 = 3, B = 100)

Value

returns a numerical matrix containing number of genes and associated p value in the intersection of 2 categories

Arguments

dir

character string full pathname to the directory acting as result repository

m1

return value of catGenes

m2

return value of catGenes

thresh1

integer acceptance threshold for the number of genes in a cat

thresh2

integer acceptance threshold for the number of common genes in 2 cats

B

integer a total bootstrap iteration

Examples

Run this code
#load("data/x_m1.RData")
#load("data/x_m2.RData")
mat<-Jaccard(dir=tempdir(),x_m1,x_m2)

Run the code above in your browser using DataLab