Learn R Programming

HTGM2D (version 1.1.1)

compareGoMinerHTGM2D: compareGoMinerHTGM2D

Description

compare the results of GoMiner and HTGM2D

Usage

compareGoMinerHTGM2D(subd, mat, l, ontologies)

Value

returns no value, but saves files that list category difference between GoMiner and HTG2D

Arguments

subd

character string full path name to the output subdirectory

mat

return value of Jaccard()

l

of return values of GoMiner()

ontologies

character vector of 2 ontologies e.g. c("biological_process","cellular_component")

Examples

Run this code
ontologies<-c("biological_process","cellular_component")
#load("data/x_l.Rdata")
#load("data/x_mat.Rdata")
subd<-tempdir()
compareGoMinerHTGM2D(subd,x_mat,x_l,ontologies)

Run the code above in your browser using DataLab