powered by
create the heat map data that is needed as input to JaccardHeatMap()
Jaccard(dir, m1, m2, thresh1 = 2, thresh2 = 3, B = 100)
returns a numerical matrix containing number of genes and associated p value in the intersection of 2 categories
character string full pathname to the directory acting as result repository
return value of catGenes
integer acceptance threshold for the number of genes in a cat
integer acceptance threshold for the number of common genes in 2 cats
integer a total bootstrap iteration
#load("data/x_m1.RData") #load("data/x_m2.RData") mat<-Jaccard(dir=tempdir(),x_m1,x_m2)
Run the code above in your browser using DataLab