powered by
compare the results of GoMiner and HTGM2D
compareGoMinerHTGM2D(subd, mat, l, ontologies)
returns no value, but saves files that list category difference between GoMiner and HTG2D
character string full path name to the output subdirectory
return value of Jaccard()
of return values of GoMiner()
character vector of 2 ontologies e.g. c("biological_process","cellular_component")
ontologies<-c("biological_process","cellular_component") #load("data/x_l.Rdata") #load("data/x_mat.Rdata") subd<-tempdir() compareGoMinerHTGM2D(subd,x_mat,x_l,ontologies)
Run the code above in your browser using DataLab